<?php
/*
 +--------------------------------------------------------------------+
 | Copyright CiviCRM LLC. All rights reserved.                        |
 |                                                                    |
 | This work is published under the GNU AGPLv3 license with some      |
 | permitted exceptions and without any warranty. For full license    |
 | and copyright information, see https://civicrm.org/licensing       |
 +--------------------------------------------------------------------+
 */

use CRM_Stripe_ExtensionUtil as E;

/**
 * Stripe.Importallcustomers
 *
 * @param array $spec description of fields supported by this API call
 */
function _civicrm_api3_stripe_importallcustomers_spec(&$spec) {
  $spec['ppid']['title'] = E::ts('Use the given Payment Processor ID');
  $spec['ppid']['type'] = CRM_Utils_Type::T_INT;
  $spec['ppid']['api.required'] = TRUE;
  $spec['create_missing_contact']['title'] = E::ts('Create missing contact');
  $spec['create_missing_contact']['description'] = E::ts('(default: true) If contact is not found in CiviCRM create it automatically');
  $spec['create_missing_contact']['type'] = CRM_Utils_Type::T_BOOLEAN;
  $spec['create_missing_contact']['api.required'] = FALSE;
  $spec['create_missing_contact']['api.default'] = TRUE;
}

/**
 * Stripe.Importallcustomers API
 *
 * @param array $params
 *
 * @return array
 * @throws \CiviCRM_API3_Exception
 */
function civicrm_api3_stripe_importallcustomers($params) {
  $importer = new \Civi\StripeImport\Customer();
  $importer->setPaymentProcessorID($params['ppid']);
  $importer->setCreateMissingContact($params['create_missing_contact']);
  $return = $importer->importAll();
  return civicrm_api3_create_success($return);
}
