<?php
/*
 +--------------------------------------------------------------------+
 | Copyright CiviCRM LLC. All rights reserved.                        |
 |                                                                    |
 | This work is published under the GNU AGPLv3 license with some      |
 | permitted exceptions and without any warranty. For full license    |
 | and copyright information, see https://civicrm.org/licensing       |
 +--------------------------------------------------------------------+
 */

use CRM_Stripe_ExtensionUtil as E;

/**
 * Stripe.Importcustomers
 *
 * @param array $spec description of fields supported by this API call
 */
function _civicrm_api3_stripe_importcustomers_spec(&$spec) {
  $spec['ppid']['title'] = E::ts('Use the given Payment Processor ID');
  $spec['ppid']['type'] = CRM_Utils_Type::T_INT;
  $spec['ppid']['api.required'] = TRUE;
  $spec['limit']['title'] = E::ts('Limit number of Customers/Subscriptions to be imported');
  $spec['limit']['type'] = CRM_Utils_Type::T_INT;
  $spec['limit']['api.required'] = FALSE;
  $spec['starting_after']['title'] = E::ts('Start importing customers after this one');
  $spec['starting_after']['type'] = CRM_Utils_Type::T_STRING;
  $spec['starting_after']['api.required'] = FALSE;
  $spec['create_missing_contact']['title'] = E::ts('Create missing contact');
  $spec['create_missing_contact']['description'] = E::ts('(default: true) If contact is not found in CiviCRM create it automatically');
  $spec['create_missing_contact']['type'] = CRM_Utils_Type::T_BOOLEAN;
  $spec['create_missing_contact']['api.required'] = FALSE;
  $spec['create_missing_contact']['api.default'] = TRUE;
  $spec['created']['type'] = CRM_Utils_Type::T_TIMESTAMP;
  $spec['created']['title'] = E::ts('Import customers before/after this date');
  $spec['created']['description'] = E::ts('Use the >,>=,<,<= operators to import customers before/after the specified date');
}

/**
 * Stripe.Importcustomers API
 *
 * @param array $params
 *
 * @return array
 * @throws \CiviCRM_API3_Exception
 * @throws \Stripe\Exception\UnknownApiErrorException
 */
function civicrm_api3_stripe_importcustomers($params) {
  $importer = new \Civi\StripeImport\Customer();
  $importer->setPaymentProcessorID($params['ppid']);
  $importer->setCreateMissingContact($params['create_missing_contact']);
  $stripeAPIFilters = [
    'created' => $params['created'] ?? NULL,
    'starting_after' => $params['starting_after'] ?? NULL,
  ];
  $return = $importer->importMultiple($params['limit'] ?? 100, $stripeAPIFilters);
  return civicrm_api3_create_success($return);
}
